==> julia-1.12.2-macaarch64.tar.gz: julia-1.12.2/share/julia/stdlib/v1.12/SparseArrays/gen/._generator.jl <==
    Mac OS X            	   2  &z     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      Q      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              q   4                     >generator A427R7F42H y*-#q0                    MKxӧ!ax                            	generator                     
*Hcd                   
*Hcd
                
subject.OU        
A427R7F42H                4                      >generator A427R7F42H z|R!A$п44!+*6̊)                                SdL\0Fh]0	*H
010
	`He 0	*H
  0>0& ?͗Iz˃Mxs]C0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
210922185510Z
310917000000Z0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0"0
	*H
  0
 ,h!TeqN
(uRDހFg) 0MLnJcLB/}%_K*To0)(4x]#*!FЉ_jq
5-'!@r7v1tpL-^Eb@7\ܥP@
#%E@g{9x43.,&%Ϊ*w_.q;Lz"Mpֆg33Z@Īs\7 00U0 0U#0+iGv	k.@GM^0D+80604+0(http://ocsp.apple.com/ocsp03-applerootca0.U'0%0#!http://crl.apple.com/root.crl0U:ivY7U0U0
*Hcd 0
	*H
  C
YCZ20V&Hc+irH[^&t#3T3"ZظKiΖ
5joΊibmJ9MעԈ3\7D7Dh
{}~̵o=zt}҈1Y`F잹@*a
pJ,Lyc%!#o[ZWEm_doD/oM=xx
V;:+eXԹ02M$9:Z\000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00!u	LrZ=0
	*H
 0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0
240912150650Z
290913150649Z010
	&,d
A427R7F42H1C0AU:Developer ID Application: Julia Computing LLC (A427R7F42H)10U
A427R7F42H10U
Julia Computing LLC10	UUS0"0
	*H
  0
 IXTVC#$
T'D`qz5c۾Lt<-ލ^R4}Gwb"BϻI٩#5=qQ_Û3(*5%b,4N	#4BMoW_ŦfL8NDJ=u"C[v8`ch%;K3ȏA'}mTl" ߲shCg]v<8i]`2Ea3/ZHLi F0B0U0 0U#0:ivY7U0r+f0d0.+0"http://certs.apple.com/devidg2.der02+0&http://ocsp.apple.com/ocsp03-devidg2010U 00
	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.07++https://www.apple.com/certificateauthority/0U%0
+0UWmDl.?^0U0
*Hcd!20140811000000Z0
*Hcd
 0
	*H
  u8V(j+FmX 0:M<Rz/<q.(ߡz=$Z-h
ׯ(ǁ4SYm$P`Δw,,ؗ'MtD!N
\F
W)ZZKxwME
Y(j9\@DztB@`V**$g߼gy;g~0Lӧ=@X#Y
ӢFZ&N1qHу!ID}ᾡ0/v|req5O+/N1Aҙ100r0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS!u	LrZ=0
	`He %0	*H
	1	*H
0	*H
	1
251120174432Z0/	*H
	1" ױP~Oףؠ
0[	*Hcd	1N0+ajO${fQP0-	`He 0 3ݴ<l,#_?_{10[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		oQvb7WHf7mr4TyR7if64ZlFQj7I=
		</data>
		<data>
		MAAzrt20sAY8bCyKGSOS+BdfPwY=
		</data>
	</array>
</dict>
</plist>
0
	*H
  !΢sM|i1\e$wٳM{0zggzՍxQq\")vM I[I(Py0__OQS(](z6JSwlf;zZ*&p;ISAɺ@!EZ\iRu61HG,D2{H_prBHrϢtf%'us r(	?QS[\v햡0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  ^N\<N%#ˀd5S:kV20251120174433Z0T
s2K
00)[D0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
251110174026Z
251222174025Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 9Bu|2'<)	ǲ)B(#b9td?/$̐JB<QvbFHErN@m֚LV֘-lcuT#Ҟ
aA(m門Z^x9ޯԭt A}S\Ը79 {2w%Sg]<G_^Yg0-g;beɥstu:=eՉȁ> F,]y* 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uh~Ɏ7A5b<G0U0
	*H
  ?W;X9&{cۘ2H8>ǲpyLtttQm3$:µsn~5ySn	ODV;)d74COz
,vm$}dc`Sg<ȜʧIvlG%Bg5NOdB[m~*.j%%G?
TT7mSKXŕ#G˫=:ocWt;?;FF4q00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS)[D0	+ 0	*H
	1
*H
	0	*H
	1
251120174433Z0#	*H
	1OǍ5+"G0+*H
	1000;4k"Q )c0
	*H
  I$k-x	Q\ycTD)VcxJx]bߝr	Ss\B81m>D>Ũ&j*([rzE3;[sn;KeR|.axA9MO]P8_X}.cy0%=Yh>Q5Hge<3 	@}n3w.3KFi^>X^T
|{e^0XsjRw<eq(`D7      

==> julia-1.12.3-macaarch64.tar.gz: julia-1.12.3/share/julia/stdlib/v1.12/SparseArrays/gen/._generator.jl <==
    Mac OS X            	   2  &{     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      Q      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              q   4                     >generator A427R7F42H y*-#q0                    MKxӧ!ax                            	generator                     
*Hcd                   
*Hcd
                
subject.OU        
A427R7F42H                4                      >generator A427R7F42H z|R!A$п44!+*6̊)                                SdL\0Fh]0	*H
010
	`He 0	*H
  0>0& ?͗Iz˃Mxs]C0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
210922185510Z
310917000000Z0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0"0
	*H
  0
 ,h!TeqN
(uRDހFg) 0MLnJcLB/}%_K*To0)(4x]#*!FЉ_jq
5-'!@r7v1tpL-^Eb@7\ܥP@
#%E@g{9x43.,&%Ϊ*w_.q;Lz"Mpֆg33Z@Īs\7 00U0 0U#0+iGv	k.@GM^0D+80604+0(http://ocsp.apple.com/ocsp03-applerootca0.U'0%0#!http://crl.apple.com/root.crl0U:ivY7U0U0
*Hcd 0
	*H
  C
YCZ20V&Hc+irH[^&t#3T3"ZظKiΖ
5joΊibmJ9MעԈ3\7D7Dh
{}~̵o=zt}҈1Y`F잹@*a
pJ,Lyc%!#o[ZWEm_doD/oM=xx
V;:+eXԹ02M$9:Z\000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00!u	LrZ=0
	*H
 0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0
240912150650Z
290913150649Z010
	&,d
A427R7F42H1C0AU:Developer ID Application: Julia Computing LLC (A427R7F42H)10U
A427R7F42H10U
Julia Computing LLC10	UUS0"0
	*H
  0
 IXTVC#$
T'D`qz5c۾Lt<-ލ^R4}Gwb"BϻI٩#5=qQ_Û3(*5%b,4N	#4BMoW_ŦfL8NDJ=u"C[v8`ch%;K3ȏA'}mTl" ߲shCg]v<8i]`2Ea3/ZHLi F0B0U0 0U#0:ivY7U0r+f0d0.+0"http://certs.apple.com/devidg2.der02+0&http://ocsp.apple.com/ocsp03-devidg2010U 00
	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.07++https://www.apple.com/certificateauthority/0U%0
+0UWmDl.?^0U0
*Hcd!20140811000000Z0
*Hcd
 0
	*H
  u8V(j+FmX 0:M<Rz/<q.(ߡz=$Z-h
ׯ(ǁ4SYm$P`Δw,,ؗ'MtD!N
\F
W)ZZKxwME
Y(j9\@DztB@`V**$g߼gy;g~0Lӧ=@X#Y
ӢFZ&N1qHу!ID}ᾡ0/v|req5O+/N1Aҙ100r0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS!u	LrZ=0
	`He %0	*H
	1	*H
0	*H
	1
251215123700Z0/	*H
	1" ױP~Oףؠ
0[	*Hcd	1N0+ajO${fQP0-	`He 0 3ݴ<l,#_?_{10[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		oQvb7WHf7mr4TyR7if64ZlFQj7I=
		</data>
		<data>
		MAAzrt20sAY8bCyKGSOS+BdfPwY=
		</data>
	</array>
</dict>
</plist>
0
	*H
  Mzb+:وGFޡ
̋6̥۶1zMƔE8n İRѲ#)#Y#;/C@^MVK']n01͌O8XePe#.;lC01ewd\JFŝux;c63Pj#1
\`ܩ'iy-rv<,i~h^gGK []yt'޺EHn(h؞͉8ZyU0*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  2%O4QrUQ'--T8*20251215123701Z0	 hQl=D
00Qw0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
251208174023Z
260119174022Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 r	%y!nfXaM6#JMi6q`t2ѷ325:Ԫa
T7\q}# TWNE^_or?/IS %`ZT|J@1Uc-o90hvi8ٖ8^0ı1#!	E|}{h`{c"J
*mЏ8lpOϿv1
&@%;?_~y 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U]m#=J.E0U0
	*H
  (v^!뎥htZl3/u[g8ϋvą)Ӈ<g dPf?~_'+(~T9SȘq*I!/H!b9	r&v:#BڳlXg;
Q5@q4icQG7}ȺS*N5
L-^Dp
"!OwH:YkrL
GX;,]^@F*i
:5-⥍t,\O100}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSQw0	+ 0	*H
	1
*H
	0	*H
	1
251215123701Z0#	*H
	1O_ڝi?v0
30+*H
	1000A=aHKԳZ(0
	*H
  wKkֱLi O+]и<ES[7=
)iK[cznUM=`{%eJ7Yp"
UêQRX$5^lq?pӹe3ٌH7iw?QtJ+.fM{+ΫtAZpz5<M@6X2l;܇|~$3^	RDst+t>(ELgf̨ve	q      
